==> opari2_2.0.4.orig.tar.gz: html/search/all_8.js <==
var searchData=
[
  ['pomp2_5fbegin',['POMP2_Begin',['../pomp2__user__lib_8h.html#a103798c6fcdee1063ff8baf88f13d8ea',1,'pomp2_user_lib.h']]],
  ['pomp2_5fdefaultsharing_5ftype',['POMP2_DefaultSharing_type',['../pomp2__region__info_8h.html#a93b8b7fd1fc771580ef1e2c6eefecc59',1,'pomp2_region_info.h']]],
  ['pomp2_5fend',['POMP2_End',['../pomp2__user__lib_8h.html#a94e19dfab1ba91569bc18c057ca5ad37',1,'pomp2_user_lib.h']]],
  ['pomp2_5ffinalize',['POMP2_Finalize',['../pomp2__user__lib_8h.html#ae172c40c40ac62b7587e1b11abfff559',1,'pomp2_user_lib.h']]],
  ['pomp2_5fget_5fnew_5ftask_5fhandle',['POMP2_Get_new_task_handle',['../pomp2__lib_8h.html#a45c8a37325b33db03c8dc30db0d3f385',1,'pomp2_lib.h']]],
  ['pomp2_5fget_5fnum_5fregions',['POMP2_Get_num_regions',['../pomp2__lib_8h.html#a5677283f76b1775959efa672bd0595af',1,'pomp2_lib.h']]],
  ['pomp2_5fget_5fopari2_5fversion',['POMP2_Get_opari2_version',['../pomp2__lib_8h.html#a64540be40e1ccb2a6084608e6b517ca4',1,'POMP2_Get_opari2_version(void):&#160;pomp2_lib.h'],['../pomp2__user__lib_8h.html#a64540be40e1ccb2a6084608e6b517ca4',1,'POMP2_Get_opari2_version(void):&#160;pomp2_user_lib.h']]],
  ['pomp2_5finit',['POMP2_Init',['../pomp2__user__lib_8h.html#a973f7b06d14fddd52ed74ee50529c284',1,'pomp2_user_lib.h']]],
  ['pomp2_5finit_5fregions',['POMP2_Init_regions',['../pomp2__lib_8h.html#a1ee3934a87de5fb3e14bbef827fc0f4c',1,'pomp2_lib.h']]],
  ['pomp2_5flib_2eh',['pomp2_lib.h',['../pomp2__lib_8h.html',1,'']]],
  ['pomp2_5foff',['POMP2_Off',['../pomp2__user__lib_8h.html#a07b65ff3417a1f6924b4a1754a5b6260',1,'pomp2_user_lib.h']]],
  ['pomp2_5fon',['POMP2_On',['../pomp2__user__lib_8h.html#a540cdb76c25649773dcec9fd6a9fac03',1,'pomp2_user_lib.h']]],
  ['pomp2_5fregion_5finfo',['POMP2_Region_info',['../structPOMP2__Region__info.html',1,'']]],
  ['pomp2_5fregion_5finfo_2eh',['pomp2_region_info.h',['../pomp2__region__info_8h.html',1,'']]],
  ['pomp2_5fregion_5ftype',['POMP2_Region_type',['../pomp2__region__info_8h.html#a680a7412e9daca09b793c6538fb7b381',1,'pomp2_region_info.h']]],
  ['pomp2_5fschedule_5ftype',['POMP2_Schedule_type',['../pomp2__region__info_8h.html#a9bada01c672e9a100dc7903ba06e76a7',1,'pomp2_region_info.h']]],
  ['pomp2_5fuser_5fassign_5fhandle',['POMP2_USER_Assign_handle',['../pomp2__user__lib_8h.html#a7589f2c2aa05b5bed5c15c9e4f07b701',1,'pomp2_user_lib.h']]],
  ['pomp2_5fuser_5fget_5fnum_5fregions',['POMP2_USER_Get_num_regions',['../pomp2__user__lib_8h.html#ae0dfec7d859997b69bbcda438dca1867',1,'pomp2_user_lib.h']]],
  ['pomp2_5fuser_5finit_5fregions',['POMP2_USER_Init_regions',['../pomp2__user__lib_8h.html#af54040ee98b4278d5b991a36b813357c',1,'pomp2_user_lib.h']]],
  ['pomp2_5fuser_5flib_2eh',['pomp2_user_lib.h',['../pomp2__user__lib_8h.html',1,'']]],
  ['pomp2_5fuser_5fregion_5finfo',['POMP2_USER_Region_info',['../structPOMP2__USER__Region__info.html',1,'']]],
  ['pomp2_5fuser_5fregion_5finfo_2eh',['pomp2_user_region_info.h',['../pomp2__user__region__info_8h.html',1,'']]],
  ['pomp2_5fuser_5fregion_5ftype',['POMP2_USER_Region_type',['../pomp2__user__region__info_8h.html#ae76f4de310f343b64c6541b68ef60600',1,'pomp2_user_region_info.h']]],
  ['pomp2defaultsharingtype2string',['pomp2defaultSharingType2String',['../pomp2__region__info_8h.html#ad0856c731e68eef9a148ab79cd0329b1',1,'pomp2_region_info.h']]],
  ['pomp2regiontype2string',['pomp2RegionType2String',['../pomp2__region__info_8h.html#a41324a61d69375fcf4d905a2db32a1b5',1,'pomp2_region_info.h']]],
  ['pomp2scheduletype2string',['pomp2ScheduleType2String',['../pomp2__region__info_8h.html#a5a45288617878806cd3773be2bad8ec4',1,'pomp2_region_info.h']]],
  ['pomp2userregiontype2string',['pomp2UserRegionType2String',['../pomp2__user__region__info_8h.html#aea1b2a34dad1e46141aa650948fbacfb',1,'pomp2_user_region_info.h']]],
  ['pomp_20user_20instrumentation',['POMP User Instrumentation',['../POMP_USER.html',1,'index']]]
];

==> opari2_2.0.9.orig.tar.gz: html/search/all_8.js <==
var searchData=
[
  ['pomp2_5fassign_5fhandle',['POMP2_Assign_handle',['../pomp2__lib_8h.html#a4ced2800b4c94cb22193e4a8b9d7a0b2',1,'pomp2_lib.h']]],
  ['pomp2_5fbegin',['POMP2_Begin',['../pomp2__user__lib_8h.html#a103798c6fcdee1063ff8baf88f13d8ea',1,'pomp2_user_lib.h']]],
  ['pomp2_5fdefaultsharing_5ftype',['POMP2_DefaultSharing_type',['../pomp2__region__info_8h.html#a93b8b7fd1fc771580ef1e2c6eefecc59',1,'pomp2_region_info.h']]],
  ['pomp2_5fend',['POMP2_End',['../pomp2__user__lib_8h.html#a94e19dfab1ba91569bc18c057ca5ad37',1,'pomp2_user_lib.h']]],
  ['pomp2_5ffinalize',['POMP2_Finalize',['../pomp2__user__lib_8h.html#ae172c40c40ac62b7587e1b11abfff559',1,'pomp2_user_lib.h']]],
  ['pomp2_5fget_5fnew_5ftask_5fhandle',['POMP2_Get_new_task_handle',['../pomp2__lib_8h.html#a45c8a37325b33db03c8dc30db0d3f385',1,'pomp2_lib.h']]],
  ['pomp2_5fget_5fnum_5fregions',['POMP2_Get_num_regions',['../pomp2__lib_8h.html#a5677283f76b1775959efa672bd0595af',1,'pomp2_lib.h']]],
  ['pomp2_5fget_5fopari2_5fversion',['POMP2_Get_opari2_version',['../pomp2__lib_8h.html#a64540be40e1ccb2a6084608e6b517ca4',1,'POMP2_Get_opari2_version(void):&#160;pomp2_lib.h'],['../pomp2__user__lib_8h.html#a64540be40e1ccb2a6084608e6b517ca4',1,'POMP2_Get_opari2_version(void):&#160;pomp2_user_lib.h']]],
  ['pomp2_5finit',['POMP2_Init',['../pomp2__user__lib_8h.html#a973f7b06d14fddd52ed74ee50529c284',1,'pomp2_user_lib.h']]],
  ['pomp2_5finit_5fregions',['POMP2_Init_regions',['../pomp2__lib_8h.html#a1ee3934a87de5fb3e14bbef827fc0f4c',1,'pomp2_lib.h']]],
  ['pomp2_5flib_2eh',['pomp2_lib.h',['../pomp2__lib_8h.html',1,'']]],
  ['pomp2_5foff',['POMP2_Off',['../pomp2__user__lib_8h.html#a07b65ff3417a1f6924b4a1754a5b6260',1,'pomp2_user_lib.h']]],
  ['pomp2_5fon',['POMP2_On',['../pomp2__user__lib_8h.html#a540cdb76c25649773dcec9fd6a9fac03',1,'pomp2_user_lib.h']]],
  ['pomp2_5fregion_5finfo',['POMP2_Region_info',['../structPOMP2__Region__info.html',1,'']]],
  ['pomp2_5fregion_5finfo_2eh',['pomp2_region_info.h',['../pomp2__region__info_8h.html',1,'']]],
  ['pomp2_5fregion_5ftype',['POMP2_Region_type',['../pomp2__region__info_8h.html#a680a7412e9daca09b793c6538fb7b381',1,'pomp2_region_info.h']]],
  ['pomp2_5fschedule_5ftype',['POMP2_Schedule_type',['../pomp2__region__info_8h.html#a9bada01c672e9a100dc7903ba06e76a7',1,'pomp2_region_info.h']]],
  ['pomp2_5fuser_5fassign_5fhandle',['POMP2_USER_Assign_handle',['../pomp2__user__lib_8h.html#a7589f2c2aa05b5bed5c15c9e4f07b701',1,'pomp2_user_lib.h']]],
  ['pomp2_5fuser_5fget_5fnum_5fregions',['POMP2_USER_Get_num_regions',['../pomp2__user__lib_8h.html#ae0dfec7d859997b69bbcda438dca1867',1,'pomp2_user_lib.h']]],
  ['pomp2_5fuser_5finit_5fregions',['POMP2_USER_Init_regions',['../pomp2__user__lib_8h.html#af54040ee98b4278d5b991a36b813357c',1,'pomp2_user_lib.h']]],
  ['pomp2_5fuser_5flib_2eh',['pomp2_user_lib.h',['../pomp2__user__lib_8h.html',1,'']]],
  ['pomp2_5fuser_5fregion_5finfo',['POMP2_USER_Region_info',['../structPOMP2__USER__Region__info.html',1,'']]],
  ['pomp2_5fuser_5fregion_5finfo_2eh',['pomp2_user_region_info.h',['../pomp2__user__region__info_8h.html',1,'']]],
  ['pomp2_5fuser_5fregion_5ftype',['POMP2_USER_Region_type',['../pomp2__user__region__info_8h.html#ae76f4de310f343b64c6541b68ef60600',1,'pomp2_user_region_info.h']]],
  ['pomp2defaultsharingtype2string',['pomp2defaultSharingType2String',['../pomp2__region__info_8h.html#ad0856c731e68eef9a148ab79cd0329b1',1,'pomp2_region_info.h']]],
  ['pomp2regiontype2string',['pomp2RegionType2String',['../pomp2__region__info_8h.html#a41324a61d69375fcf4d905a2db32a1b5',1,'pomp2_region_info.h']]],
  ['pomp2scheduletype2string',['pomp2ScheduleType2String',['../pomp2__region__info_8h.html#a5a45288617878806cd3773be2bad8ec4',1,'pomp2_region_info.h']]],
  ['pomp2userregiontype2string',['pomp2UserRegionType2String',['../pomp2__user__region__info_8h.html#aea1b2a34dad1e46141aa650948fbacfb',1,'pomp2_user_region_info.h']]],
  ['pomp_20user_20instrumentation',['POMP User Instrumentation',['../POMP_USER.html',1,'index']]]
];
